@@ -65,6 +65,7 @@ BarcodeDetector::BarcodeDetector() {
     // init from maemo-barcode.c
     scanning_status = false;
     this->dmtx_timer = clock(); // set initial clock time
+    //inAnalysisFn = false;
 }
 
 BarcodeDetector::~BarcodeDetector() {
@@ -274,11 +275,15 @@ int BarcodeDetector::getAnalysedImageResult(){
 
 int BarcodeDetector::analyseImage(char *buffer, int frame_width, int frame_height, char *fourcc, int bpp) {
 
-    if(scanning_status==false)
+    if(scanning_status==false) // || inAnalysisFn==true)
         return 0;
 
-    if(frame_width>MAX_VIDEO_WIDTH || frame_height>MAX_VIDEO_HEIGHT)
+    //inAnalysisFn=true; // try to stop this function from being called again when it's already running
+
+    if(frame_width>MAX_VIDEO_WIDTH || frame_height>MAX_VIDEO_HEIGHT){
+        //inAnalysisFn=false;
         return -1; // data too large
+    }
 
     if (!this->dmtx_thread.isRunning()){
         qDebug() << "Start dmtx thread running";
@@ -308,6 +313,7 @@ int BarcodeDetector::analyseImage(char *buffer, int frame_width, int frame_heigh
 
         // check and see if it has decoded something
         if(this->dmtx_thread.hasFoundBarcode){
+            //scanning_status=false; // see if we can stop double scans
             qDebug() << "analyse_image(): found datamatrix";
             // it has decoded something)
             //strcpy(*output, thread_output); // make output a pointer to the thread shared output buffer
@@ -340,6 +346,8 @@ int BarcodeDetector::analyseImage(char *buffer, int frame_width, int frame_heigh
                                QString::fromUtf8(this->dmtx_thread.thread_output),
                                qi); // *output
 
+            //inAnalysisFn=false;
+
             return ZBAR_QRCODE; // QR is also 2D so achieves the same effect //BARCODE_TYPE_DMTX;
 
         // thread is not running, check to see whether enough time has elapsed to start it running again...
@@ -391,6 +399,7 @@ int BarcodeDetector::analyseImage(char *buffer, int frame_width, int frame_heigh
 
         // check and see if it has decoded something
         if(this->zbar_thread.hasFoundBarcode){
+            //scanning_status=false; // see if we can stop double scans
             qDebug() << "analyse_image(): found ZBar barcode, zbar_thread.hasReturned=" << this->zbar_thread.hasFoundBarcode;
             // it has decoded something)
             //strcpy(*output, thread_output); // make output a pointer to the thread shared output buffer
@@ -411,6 +420,7 @@ int BarcodeDetector::analyseImage(char *buffer, int frame_width, int frame_heigh
                                QString::fromUtf8(this->zbar_thread.thread_output),
                                qi); // *output
 
+            //inAnalysisFn=false;
             return ZBAR_QRCODE; // not sure this makes any odds anymore anyway.
 
 
@@ -436,7 +446,7 @@ int BarcodeDetector::analyseImage(char *buffer, int frame_width, int frame_heigh
 //        qDebug() << "analyse_image() zbar thread is decoding";
     }
 
-
+    //inAnalysisFn=false;
     return 0; // generic, as we're not using the return type anymore, best turn into a void fn eventually
 
 
