@@ -33,8 +33,8 @@
 #ifndef COMMON_H
 #define COMMON_H
 
-// avoid API warnings
-#define GST_USE_UNSTABLE_API
+#define DEBUGINFO QString(__FUNCTION__) + QString("():")
+
 // Definitions
 
 #define DEVICE_UNKNOWN  -1
