@@ -848,8 +848,14 @@ void VideoWidget::getDeviceType() {
     } else
         qDebug( "Oh no... We're something else.");
 }
+
 void VideoWidget::refocus() {
-    if(!focusing && pipelineReady && this->decoder->scanning_status) { // we are running and are not focusing.
+    if(!focusing && pipelineReady) { // we are running and are not focusing.
+
+        // if we're in continous scanning mode, but not yet scanning, don't autofocus - to avoid autofocus while we're in resultswindow, etc
+        if(!this->decoder->scanning_status && parent->continuousScanningMode)
+            return;
+
         emit focusingValueChanged(true);
         gst_element_set_state (pipeline, GST_STATE_PAUSED);
 
@@ -862,7 +868,12 @@ void VideoWidget::refocus() {
         gst_element_set_state (pipeline, GST_STATE_PLAYING);
         //        refocusTimer->start(); // try to refocus using the pre-set interval
     } else {
-        qDebug("VideoWidget::refocus(): Already attempting autofocus or pipeline not ready... Please wait :)");
+        if(focusing)
+            qDebug("VideoWidget::refocus(): Already attempting autofocus... Please wait :)");
+        else if(!pipelineReady)
+            qDebug("VideoWidget::refocus(): Pipeline not ready... Please wait :)");
+        else if(!this->decoder->scanning_status)
+            qDebug("VideoWidget::refocus(): Not decoding... Please wait :)");
     }
 }
 void VideoWidget::setFocusing(bool enabled) {
